@@ -71,7 +71,7 @@ cnd_body <- function(cnd, ...) {
     override_cnd_body(cnd, ...)
   }
 }
-#' @method cnd_body default
+#' @export
 cnd_body.default <- function(cnd, ...) {
   chr()
 }
@@ -84,10 +84,10 @@ override_cnd_body <- function(cnd, ...) {
   } else if (is_bare_formula(body)) {
     body <- as_function(body)
     body(cnd, ...)
-  } else if (is_character(body)) {
+  } else if (is_string(body)) {
     body
   } else {
-    abort("`body` must be `TRUE` or a function.")
+    abort("`body` must be a string or a function.")
   }
 }
 
