@@ -1134,7 +1134,7 @@ new_overscope <- function(bottom, top = NULL, enclosure = NULL) {
     "`new_overscope()` is deprecated as of rlang 0.2.0.",
     "Please use `new_data_mask()` instead."
   ))
-  new_data_mask(bottom, top, enclosure)
+  new_data_mask(bottom, top)
 }
 #' @rdname as_overscope
 #' @param overscope A data mask.
@@ -1998,3 +1998,48 @@ scoped_options <- function(..., .frame = caller_env()) {
 scoped_bindings <- function(..., .env = .frame, .frame = caller_env()) {
   local_bindings(..., .env = .env, .frame = .frame)
 }
+
+
+#  Superseded
+
+#' Mask bindings by defining symbols deeper in a scope
+#'
+#' @description
+#' \Sexpr[results=rd, stage=render]{rlang:::lifecycle("superseded")}
+#'
+#' This function is superseded. Please use [env()] (and possibly
+#' [set_env()] if you're masking the bindings for another object like
+#' a closure or a formula) instead.
+#'
+#' `env_bury()` is like [env_bind()] but it creates the bindings in a
+#' new child environment. This makes sure the new bindings have
+#' precedence over old ones, without altering existing environments.
+#' Unlike `env_bind()`, this function does not have side effects and
+#' returns a new environment (or object wrapping that environment).
+#'
+#' @inheritParams env_bind
+#' @return A copy of `.env` enclosing the new environment containing
+#'   bindings to `...` arguments.
+#' @seealso [env_bind()], [env_unbind()]
+#'
+#' @keywords internal
+#' @export
+#' @examples
+#' orig_env <- env(a = 10)
+#' fn <- set_env(function() a, orig_env)
+#'
+#' # fn() currently sees `a` as the value `10`:
+#' fn()
+#'
+#' # env_bury() will bury the current scope of fn() behind a new
+#' # environment:
+#' fn <- env_bury(fn, a = 1000)
+#' fn()
+#'
+#' # Even though the symbol `a` is still defined deeper in the scope:
+#' orig_env$a
+env_bury <- function(.env, ...) {
+  env_ <- get_env(.env)
+  env_ <- child_env(env_, ...)
+  set_env(.env, env_)
+}
