@@ -36,6 +36,16 @@ test_that("set_names() coerces to character", {
   expect_identical(set_names(1:2, "a", TRUE), c(a = 1L, `TRUE` = 2L))
 })
 
+test_that("set_names() checks length generically", {
+  x <- as.POSIXlt("1970-01-01", tz = "UTC")
+
+  expect <- x
+  names(expect) <- "a"
+
+  expect_identical(set_names(x, "a"), expect)
+  expect_error(set_names(x, c("a", "b")), "the same length")
+})
+
 test_that("has_name() works with pairlists", {
   expect_true(has_name(fn_fmls(`[.data.frame`), "drop"))
 })
@@ -45,3 +55,8 @@ test_that("set_names() first names the vector before applying a function (#688)"
   expect_identical(set_names(set_names(letters), toupper), exp)
   expect_identical(set_names(letters, toupper), exp)
 })
+
+test_that("set_names2() fills in empty names", {
+  chr <- c("a", b = "B", "c")
+  expect_equal(set_names2(chr), c(a = "a", b = "B", c = "c"))
+})
